@@ -3,6 +3,7 @@ import argparse
 from pdm import termui
 from pdm.cli.commands.base import BaseCommand
 from pdm.project import Project
+from pdm.project.config import Config
 
 
 class Command(BaseCommand):
@@ -32,39 +33,59 @@ class Command(BaseCommand):
             self._list_config(project, options)
 
     def _get_config(self, project: Project, options: argparse.Namespace) -> None:
+        if options.key in project.project_config.deprecated:
+            project.core.ui.echo(
+                "DEPRECATED: the config has been renamed to "
+                f"{project.project_config.deprecated[options.key]}",
+                fg="yellow",
+                err=True,
+            )
+            options.key = project.project_config.deprecated[options.key]
         project.core.ui.echo(project.config[options.key])
 
     def _set_config(self, project: Project, options: argparse.Namespace) -> None:
         config = project.project_config if options.local else project.global_config
+        if options.key in config.deprecated:
+            project.core.ui.echo(
+                "DEPRECATED: the config has been renamed to "
+                f"{config.deprecated[options.key]}",
+                fg="yellow",
+                err=True,
+            )
         config[options.key] = options.value
 
+    def _show_config(self, config: Config, ui: termui.UI) -> None:
+        for key in sorted(config):
+            config_item = config._config_map[key]
+            deprecated = ""
+            if config_item.replace and config_item.replace in config._data:
+                deprecated = termui.red(f"(deprecating: {config_item.replace})")
+            ui.echo(
+                termui.yellow("# " + config_item.description),
+                verbosity=termui.DETAIL,
+            )
+            ui.echo(f"{termui.cyan(key)}{deprecated} = {config[key]}")
+
     def _list_config(self, project: Project, options: argparse.Namespace) -> None:
         ui = project.core.ui
-        ui.echo("Home configuration ({}):".format(project.global_config._config_file))
+        ui.echo("Home configuration ({}):".format(project.global_config.config_file))
         with ui.indent("  "):
-            for key in sorted(project.global_config):
-                ui.echo(
-                    termui.yellow(
-                        "# " + project.global_config._config_map[key].description
-                    ),
-                    verbosity=termui.DETAIL,
-                )
-                ui.echo(f"{termui.cyan(key)} = {project.global_config[key]}")
+            self._show_config(project.global_config, ui)
 
         ui.echo()
         ui.echo(
-            "Project configuration ({}):".format(project.project_config._config_file)
+            "Project configuration ({}):".format(project.project_config.config_file)
         )
         with ui.indent("  "):
-            for key in sorted(project.project_config):
-                ui.echo(
-                    termui.yellow(
-                        "# " + project.project_config._config_map[key].description
-                    ),
-                    verbosity=termui.DETAIL,
-                )
-                ui.echo(f"{termui.cyan(key)} = {project.project_config[key]}")
+            self._show_config(project.project_config, ui)
 
     def _delete_config(self, project: Project, options: argparse.Namespace) -> None:
         config = project.project_config if options.local else project.global_config
+        if options.key in config.deprecated:
+            project.core.ui.echo(
+                "DEPRECATED: the config has been renamed to "
+                f"{config.deprecated[options.key]}",
+                fg="yellow",
+                err=True,
+            )
         del config[options.key]
