@@ -181,10 +181,13 @@ def test_import_requirement_no_overwrite(project, invoke, tmp_path):
 
 
 @pytest.mark.network
-def test_search_package(invoke):
-    result = invoke(["search", "requests"])
+def test_search_package(invoke, tmp_path):
+    with cd(tmp_path):
+        result = invoke(["search", "requests"])
     assert result.exit_code == 0
     assert len(result.output.splitlines()) > 0
+    assert not tmp_path.joinpath("__pypackages__").exists()
+    assert not tmp_path.joinpath(".pdm.toml").exists()
 
 
 @pytest.mark.network
@@ -259,11 +262,32 @@ def test_lock_refresh(invoke, project, repository):
     result = invoke(["lock"], obj=project)
     assert result.exit_code == 0
     assert project.is_lockfile_hash_match()
+    assert not project.lockfile["metadata"]["files"].get("requests 2.19.1")
     project.add_dependencies({"requests": parse_requirement("requests>=2.0")})
+    repository.get_hashes = (
+        lambda c: {"requests-2.19.1-py3-none-any.whl": "sha256:abcdef123456"}
+        if c.identify() == "requests"
+        else {}
+    )
     assert not project.is_lockfile_hash_match()
     result = invoke(["lock", "--refresh"], obj=project)
     assert result.exit_code == 0
     assert project.is_lockfile_hash_match()
+    assert project.lockfile["metadata"]["files"]["requests 2.19.1"][0] == {
+        "file": "requests-2.19.1-py3-none-any.whl",
+        "hash": "sha256:abcdef123456",
+    }
+
+
+def test_lock_refresh_keep_consistent(invoke, project, repository):
+    project.add_dependencies({"requests": parse_requirement("requests")})
+    result = invoke(["lock"], obj=project)
+    assert result.exit_code == 0
+    assert project.is_lockfile_hash_match()
+    previous = project.lockfile_file.read_text()
+    result = invoke(["lock", "--refresh"], obj=project)
+    assert result.exit_code == 0
+    assert project.lockfile_file.read_text() == previous
 
 
 @pytest.mark.network
